SWDEV-269246 - Added missing exports for hipArrayDestroy
Change-Id: I730814720bb618e895efbe2f412e437110bed8bc
[ROCm/clr commit: 9f142f988d]
Этот коммит содержится в:
коммит произвёл
Arya Rafii
родитель
2b715e4826
Коммит
cd4aec747f
@@ -2300,6 +2300,8 @@ hipError_t hipMallocArray(hipArray** array, const hipChannelFormatDesc* desc, si
|
||||
size_t height __dparm(0), unsigned int flags __dparm(hipArrayDefault));
|
||||
hipError_t hipArrayCreate(hipArray** pHandle, const HIP_ARRAY_DESCRIPTOR* pAllocateArray);
|
||||
|
||||
hipError_t hipArrayDestroy(hipArray* array);
|
||||
|
||||
hipError_t hipArray3DCreate(hipArray** array, const HIP_ARRAY3D_DESCRIPTOR* pAllocateArray);
|
||||
|
||||
hipError_t hipMalloc3D(hipPitchedPtr* pitchedDevPtr, hipExtent extent);
|
||||
|
||||
@@ -84,6 +84,7 @@ hipMalloc3DArray
|
||||
hipMallocManaged
|
||||
hipArrayCreate
|
||||
hipArray3DCreate
|
||||
hipArrayDestroy
|
||||
hipMallocArray
|
||||
hipMemAdvise
|
||||
hipMemAllocPitch
|
||||
|
||||
@@ -85,6 +85,7 @@ global:
|
||||
hipMalloc3DArray;
|
||||
hipMallocManaged;
|
||||
hipArrayCreate;
|
||||
hipArrayDestroy;
|
||||
hipArray3DCreate;
|
||||
hipMallocArray;
|
||||
hipMallocPitch;
|
||||
|
||||
Ссылка в новой задаче
Block a user